@@ -56,7 +56,7 @@ CODE facilitynames[] =
 
 static int LOG(int, const char *, ...);
 int dgconfig_loglevel;
-int (*dgconfig_log) (int, const char *, ...) = syslog;
+int (*dgconfig_log) (int, const char *, ...) = (void *) syslog;
 
 
 /*--- Ϣؿ ---*/
@@ -329,14 +329,14 @@ read_config(char *file, struct cfentry *cfe, int count, void *data)
                             error++;
                             break;
                         } else {
-                            if ((value == LONG_MAX) && (errno == ERANGE)) {
+                            if ((value == UINT_MAX) && (errno == ERANGE)) {
                                 SYSLOG(LOG_WARNING, ERR_CONF_TOOBIGNUM,
                                        file, nline);
                                 error++;
                                 break;
                             }
                             if ((cfe[i].cf_type == CF_INT_PLUS) &&
-                                (value > LONG_MAX)) {
+                                (value > UINT_MAX)) {
                                 SYSLOG(LOG_WARNING, ERR_CONF_MUSTPLUS,
                                        file, nline, cfe[i].cf_name, value);
                                 error++;
