@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: log.h,v $
- * $Revision: 1.6 $
- * $Date: 2010/03/18 05:45:02 $
+ * $Revision: 1.15 $
+ * $Date: 2010/09/27 07:33:44 $
  */
 
 #define SYSLOG_IDENT "samma"
@@ -33,7 +33,7 @@
 #define STDERR_CONFIG_READ		"Cannot load samma config.(%s)"
 #define ERR_CONFIG_RELOADING		"%s: Cannot reload config(%s): (still refered)"
 #define CONFIG_RELOADING		"%s: reload config(%s)"
-#define ERR_TEMPLATE_READ		"%s: Cannot reload template file.(%s)"
+#define ERR_TEMPLATE_READ		"%s: Template file is empty.(%s)"
 #define ERR_TEMPLATE_RELOADING		"%s: Cannot reload template(%s): (still refered)"
 #define TEMPLATE_RELOADING		"%s: reload template(%s)"
 
@@ -67,7 +67,7 @@
 #define ERR_FILE_RENAME		"%s: Cannot rename.(%s): (%s)"
 #define ERR_FILE_OPEN		"%s: Cannot open file.(%s)"
 #define ERR_FILE_REMOVE		"%s: Cannot remove file.(%s)"
-#define ERR_FILE_GET_INFO	"%s: Cannot get file information.(%s): (%s)"
+#define ERR_FILE_GET_INFO	"%s: Cannot get file information.(%s)"
 #define ERR_FILE_CREATE_TMPFILE	"%s: Cannot create tmpfile.(%s): (%s)"
 #define ERR_FILE_WRITE		"%s: Cannot write file."
 #define ERR_FILE_GET_NAME	"%s: Cannot get file name."
@@ -118,6 +118,22 @@
 #define ERR_STR_CODE		"Invalid str code."
 #define ERR_NULL_VALUE		"Invalid value."
 #define ERR_DEFALT_ENCRYPTION	"Invalid default encryption strings."
+#define ERR_LDAP_FILTER		"Invalid LDAP filter strings."
+
+#define ERR_LDAP_SEARCH	        "%s: Cannot search ldap.(%s):"
+#define ERR_LDAP_ENTRIE 	"%s: Cannot get first ldap entry .(variable=%s):"
+#define ERR_LDAP_COUNT          "%s: Cannot count ldap.(variable=%s):"
+#define ERR_LDAP_GET_DN         "%s: Cannot get ldap dn.(variable=%s):"
+#define ERR_LDAP_INIT           "%s: Cannot ldap init.(%s):"
+#define ERR_LDAP_SET            "%s: Cannot ldap set.(%s):"
+#define ERR_LDAP_BIND           "%s: Cannot ldap bind.(%s):"
+#define ERR_LDAP_VALUE	        "%s: Cannot get value from entry.(%s):"
+
+#define ERR_YESNO		"Invalid strings."
+#define ERR_LDAP		"%s: Ldap error.(variable=%s):"
+#define ERR_MAKE_FILTER		"%s: Cannot make filter(variable=%s)"
+
+#define ERR_LDAP_CONFIG		"%s must be set.(because UserPolicy is YES)"
 
 int syslog_facility(char *str);
 void init_log();
