@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: mailzip.c,v $
- * $Revision: 1.19 $
- * $Date: 2010/09/27 07:33:44 $
+ * $Revision: 1.21 $
+ * $Date: 2011/08/15 07:10:43 $
  */
 
 #include <stdio.h>
@@ -188,7 +188,7 @@ mlfi_envrcpt(SMFICTX *ctx, char **rcptto)
     DEBUGLOG("mlfi_envrcpt start");
 
     /* get mail addr */
-    rcptaddr = get_addrpart((unsigned char *)*rcptto);
+    rcptaddr = get_addrpart_notranslate((unsigned char *)*rcptto);
     if (rcptaddr == NULL) {
 	if (rcptaddr != NULL) {
             free(rcptaddr);
@@ -364,6 +364,12 @@ mlfi_eom(SMFICTX *ctx)
         return SMFIS_TEMPFAIL;
     } else if (ret == ZIP_CONVERT_ACCEPT) {
         return SMFIS_ACCEPT;
+    } else if (ret == ZIP_CONVERT_INVALID_FILENAME) {
+        if (smfi_setreply(ctx, CODE_INVALID_FILENAME, XCODE_INVALID_FILENAME,
+                          MESSAGE_INVALID_FILENAME) != MI_SUCCESS) {
+            return SMFIS_TEMPFAIL;
+        }
+	return SMFIS_REJECT;
     }
 
     return SMFIS_CONTINUE;
