@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: mailzip.h,v $
- * $Revision: 1.7 $
- * $Date: 2010/04/10 03:01:02 $
+ * $Revision: 1.8 $
+ * $Date: 2011/07/29 03:03:03 $
  */
 
 #define IDENT   		"samma"
@@ -40,6 +40,9 @@
 #define MLFIABORT		1
 #define BEFOR_RCPTCHECK		0
 #define AFTER_RCPTCHECK		1
+#define CODE_INVALID_FILENAME	"550"
+#define XCODE_INVALID_FILENAME	"5.7.1"
+#define MESSAGE_INVALID_FILENAME "Your attachment filename may include invalid encoding. Please rename attachment file and resend."
 
 /* milter */
 sfsistat mlfi_connect(SMFICTX *, char *, _SOCK_ADDR *);
