@@ -452,7 +452,7 @@ search_rcptaddr_bdb(struct search_res *res, struct config *cfg, char *rcptaddr,
 
     /* translate lower string */
     searchaddr = str_tolower(rcptaddr);
-    if (rcptaddr == NULL) {
+    if (searchaddr == NULL) {
         /* malloc error */
         return MALLOC_ERROR;
     }
@@ -476,22 +476,25 @@ search_rcptaddr_bdb(struct search_res *res, struct config *cfg, char *rcptaddr,
 
     ret = search_rcptstr_bdb(res->rcpt_dbp, cfg->cf_rcptdbpath, rcptaddr, fqdn,
 			     res->onetime_pass, passlist, rdmpasslist);
-    free(searchaddr);
     if (ret < 0) {
+        free(searchaddr);
         return DB_ERROR;
     } else if ((ret == NOT_ENC) || (ret == ENC)) {
+        free(searchaddr);
 	return RECORD_FOUND;
     }
 
     /* search subdomain */
     ret = search_subdomain_bdb(res->rcpt_dbp, cfg->cf_rcptdbpath, fqdn, &subdomain, &passwd);
     if (ret < 0) {
+        free(searchaddr);
 	return DB_ERROR;
     } else if (ret == NOT_ENC) {
         if (passwd != NULL) {
             free(passwd);
             passwd = NULL;
         }
+        free(searchaddr);
 	return RECORD_FOUND;
     }
     if (ret == ENC) {
@@ -507,6 +510,7 @@ search_rcptaddr_bdb(struct search_res *res, struct config *cfg, char *rcptaddr,
             passwd = NULL;
 
             if (add_enclist(&passlist, subdomain, rcptaddr, tmppass) !=      0) {
+                free(searchaddr);
                 return MALLOC_ERROR;
             }
 
@@ -514,13 +518,16 @@ search_rcptaddr_bdb(struct search_res *res, struct config *cfg, char *rcptaddr,
         } else {
             /* Add rdmpasslist list */
             if (add_enclist(&rdmpasslist, OTHERKEYWORD, rcptaddr, res->onetime_pass) != 0) {
+                free(searchaddr);
                 return MALLOC_ERROR;
             }
             DEBUGLOG("Add keyword to rdmpasslist structure.(%s)", rcptaddr);
         }
+        free(searchaddr);
         return RECORD_FOUND;
     }
 
+    free(searchaddr);
     return RECORD_NOTFOUND;
 }
 
