@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: zipconv.c,v $
- * $Revision: 1.19 $
- * $Date: 2010/11/05 06:20:17 $
+ * $Revision: 1.21 $
+ * $Date: 2011/07/29 03:03:03 $
  */
 
 #include <stdio.h>
@@ -123,7 +123,8 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
     struct mailzip mz;
     struct rcptinfo *p;
     int i, ret;
-    char *temp = NULL, *notify_message, *rcptaddr;
+    char *temp = NULL, *notify_message, *rcptaddr, *confirmation_message;
+    char *org_p;
 
     memset(&mz, 0, sizeof(struct mailzip));
 
@@ -135,6 +136,9 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
     } else if (ret == PM_FAILED) {
 	mailzip_clean(mz);
 	return ZIP_CONVERT_FAILED;
+    } else if (ret == PM_INVALID_FILENAME) {
+	mailzip_clean(mz);
+	return ZIP_CONVERT_INVALID_FILENAME;
     }
 
     if (mk_encpath(cfg, &mz) == -1) {
@@ -159,11 +163,32 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
 		mailzip_clean(mz);
 		return ZIP_CONVERT_FAILED;
 	    }
+            /* send confirmation mail */
+            if ((cfg->cf_fixedpassnotify[0] == 'Y' || cfg->cf_fixedpassnotify[0] == 'y')) {
+                org_p = p->passwd;	/* save original password */
+                p->passwd = cfg->cf_fixedpassnotifypass;
+	        temp = tmpl_init();
+	        if (tmpl_tag_replace(temp, mz, p, from, &confirmation_message) != 0){
+	            mailzip_clean(mz);
+	            return ZIP_CONVERT_FAILED;
+	        }
+                p->passwd = org_p;	/* restore original password */
+	        tmpl_release(temp);
+
+	        if (passwd_sendmail(cfg, from, confirmation_message) != 0) {
+	            free(confirmation_message);
+	            mailzip_clean(mz);
+	            return ZIP_CONVERT_FAILED;
+	        }
+	        free(confirmation_message);
+            }
+
 	    if (unlink(mz.encfilepath) == -1) {
 		log(ERR_FILE_REMOVE, "convert_zip", unlink(mz.encfilepath));
 		mailzip_clean(mz);
 		return ZIP_CONVERT_FAILED;
 	    }
+
             for (i = 0; (p->rcptlist + i)->rcpt_addr != NULL; i++) {
                 rcptaddr = (p->rcptlist + i)->rcpt_addr;
                 /* delete from envelope to */
@@ -565,6 +590,7 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     FILE *rfp;
     char *tmpdir, *tmpstr;
     int rfd, len;
+    int ret;
 
     pthread_mutex_lock(&gmime_lock);
 
@@ -661,9 +687,14 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     }
     free(tmpstr);
 
-    if (drop_file(object, cfg, mz) != 0) {
+    if ((ret = drop_file(object, cfg, mz)) != 0) {
         g_object_unref (object);
 	pthread_mutex_unlock(&gmime_lock);
+        if (ret == -2) {
+            /* could not detect/convert attached filename's encoding
+             * returning specific value */
+            return(PM_INVALID_FILENAME);
+        }
 	return -1;
     }
 
@@ -739,7 +770,9 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
 	    log(ERR_CHARCODE_CONVERT, "drop_file");
             g_object_unref (att);
 	    free(tmpname);
-	    return -1;
+            /* could not detect/convert encoding
+             * returning specific value */
+	    return -2;
 	}
 	free(tmpname);
 
